# Welcome!

Contributions to aiven-client are very welcome. Please follow our guidelines:

- It's recommended to open an issue to discuss a feature before putting in a lot of effort.

- We use [GitHub Flow](https://guides.github.com/introduction/flow/), check that your main branch is up to date, and create a new branch for changes.

- Commit messages should describe the changes, not the filenames. Win our admiration by following the [excellent advice from Chris Beams](https://chris.beams.io/posts/git-commit/) when composing commit messages.

- Choose a meaningful title for your pull request.

- The pull request description should focus on what changed and why.

- Check that the tests pass (and add test coverage for your changes if appropriate).

- Stay in touch with us if we have follow up questions or requests for further changes.
